Skip to main content

jspcapy

NOTE: This repository has been officially deprecated and merged into jspcap.

This program depends on jspcap and jsformat.

jspcapy is a command line pcap file analyser tool. It supports analysis on several networking protocol headers, such as IP (both version 4 and 6), ICMP, TCP, UDP, SCTP, et al and streaming output of plist, json and tree-view text file.

  Notice that the whole project works on Python versions since 3.6.


Installation

  Simply run the following to install the latest from PyPI:

$ pip install jspcapy

  Or install from the git repository:

$ git clone https://github.com/JarryShaw/jspcapy.git
$ python setup.py install

 

Usage

  As it shows in the help manual, it is quite easy to use:

$ jspcapy -h
usage: jspcapy [-h] [-V] [-o file-name] [-f format] [-j] [-p] [-t] [-a] [-F]
               [-v]
               input-file-name

PCAP file extractor and formatted exporter

positional arguments:
  input-file-name       The name of input pcap file. If ".pcap" omits, it will
                        be automatically appended.

optional arguments:
  -h, --help            show this help message and exit
  -V, --version         show program's version number and exit
  -o file-name, --output file-name
                        The name of input pcap file. If format extension
                        omits, it will be automatically appended.
  -f format, --format format
                        Print a extraction report in the specified output
                        format. Available are all formats supported by
                        jsformat, e.g.: json, plist, and tree.
  -j, --json            Display extraction report as json. This will yield
                        "raw" output that may be used by external tools. This
                        option overrides all other options.
  -p, --plist           Display extraction report as macOS Property List
                        (plist). This will yield "raw" output that may be used
                        by external tools. This option overrides all other
                        options.
  -t, --tree            Display extraction report as tree view text. This will
                        yield "raw" output that may be used by external tools.
                        This option overrides all other options.
  -a, --auto-extension  If output file extension omits, append automatically.
  -F, --files           Split each frame into different files.
  -v, --verbose         Show more information.

  Under most circumstances, you should indicate the name of input pcap file (extension may omit) and at least, output format (json, plist, or tree). Once format unspecified, the name of output file must have proper extension (*.json, *.plist, or *.txt), otherwise FormatError will raise.

  As for verbose mode, detailed information will print while extraction (as following examples). And auto-extension flag works for the output file, to indicate whether extensions should be appended.

 

Samples

  Here are some usage samples:

  • export to a macOS Property List (Xcode has special support for this format)
$ jspcapy in -f plist --verbose
🚨Loading file 'in.pcap'
 - Frame   1: Ethernet:IPv6:ICMPv6
 - Frame   2: Ethernet:IPv6:ICMPv6
 - Frame   3: Ethernet:IPv4:TCP
 - Frame   4: Ethernet:IPv4:TCP
 - Frame   5: Ethernet:IPv4:TCP
 - Frame   6: Ethernet:IPv4:UDP
🍺Report file stored in 'out.plist'
  • export to a json file (with no format specified)
$ jspcapy in -o out.json --verbose
🚨Loading file 'in.pcap'
- Frame   1: Ethernet:IPv6:ICMPv6
- Frame   2: Ethernet:IPv6:ICMPv6
- Frame   3: Ethernet:IPv4:TCP
- Frame   4: Ethernet:IPv4:TCP
- Frame   5: Ethernet:IPv4:TCP
- Frame   6: Ethernet:IPv4:UDP
🍺Report file stored in 'out.json'
  • export to a text tree view file (without extension autocorrect)
$ jspcapy in -o out -f tree --verbos
🚨Loading file 'in.pcap'
- Frame   1: Ethernet:IPv6:ICMPv6
- Frame   2: Ethernet:IPv6:ICMPv6
- Frame   3: Ethernet:IPv4:TCP
- Frame   4: Ethernet:IPv4:TCP
- Frame   5: Ethernet:IPv4:TCP
- Frame   6: Ethernet:IPv4:UDP
🍺Report file stored in 'out'

Release files for jspcapy 0.4.0.post2

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for jspcapy 0.4.0.post2
File Size Uploaded
jspcapy-0.4.0.post2.tar.gz 16.5 kB Details

Built distributions (wheels)

Table of built distributions (wheels) for jspcapy 0.4.0.post2
File
jspcapy-0.4.0.post2-py3.7.egg Legacy Egg format - - Details
jspcapy-0.4.0.post2-py3.6.egg Legacy Egg format - - Details
jspcapy-0.4.0.post2-py3.5.egg Legacy Egg format - - Details
jspcapy-0.4.0.post2-py3.4.egg Legacy Egg format - - Details
jspcapy-0.4.0.post2-py2.7.egg Legacy Egg format - - Details
jspcapy-0.4.0.post2-pp35-none-macosx_10_14_x86_64.whl PyPy 3.5 none macOS 10.14+ x86-64 Details
jspcapy-0.4.0.post2-pp27-none-macosx_10_14_x86_64.whl PyPy 2.7 none macOS 10.14+ x86-64 Details
jspcapy-0.4.0.post2-cp37-none-macosx_10_14_x86_64.whl CPython 3.7 none macOS 10.14+ x86-64 Details
jspcapy-0.4.0.post2-cp36-none-macosx_10_14_x86_64.whl CPython 3.6 none macOS 10.14+ x86-64 Details
jspcapy-0.4.0.post2-cp27-none-macosx_10_14_x86_64.whl CPython 2.7 none macOS 10.14+ x86-64 Details

Total release size: 125.5 kB

Release files / jspcapy-0.4.0.post2.tar.gz

Download URL jspcapy-0.4.0.post2.tar.gz
Size 16.5 kB
Tags Source
SHA-256 checksum
How to use checksums
6b136f07da3097884e9a6d2373cccc256e5a79df9eb28b84b36978391eaffd1e
BLAKE2b-256 checksum
How to use checksums
dad3b21d11a8fba82588abdcbca4a686ce330b13d80be5a4e51929914d212889
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-py3.7.egg

Download URL jspcapy-0.4.0.post2-py3.7.egg
Size 5.8 kB
Tags Egg
SHA-256 checksum
How to use checksums
1f8e28d71defd9334b2bfef409412006857dd90e1d3f8e7247986ccd4b727d43
BLAKE2b-256 checksum
How to use checksums
1ac3dc5382c73304d1b7a04b89324c38152db75db8a3884089bd1042507c3255
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-py3.6.egg

Download URL jspcapy-0.4.0.post2-py3.6.egg
Size 5.8 kB
Tags Egg
SHA-256 checksum
How to use checksums
25f1fccce29074adba4e85d50909ee28642d0991bff8520ab8763fafffb50241
BLAKE2b-256 checksum
How to use checksums
b861f42f20d656ac8267306b79ad6b707660a0c04745f5a22fb29611a9f71eeb
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-py3.5.egg

Download URL jspcapy-0.4.0.post2-py3.5.egg
Size 4.3 kB
Tags Egg
SHA-256 checksum
How to use checksums
53769afc51cb5bc7204ff8e55b608a63e3a990372ea3154647e9e7dd5532a120
BLAKE2b-256 checksum
How to use checksums
8e318bc9a22266cb8a4371e80f710083ecc160f2a940aa44503c68b3a09728c6
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-py3.4.egg

Download URL jspcapy-0.4.0.post2-py3.4.egg
Size 4.3 kB
Tags Egg
SHA-256 checksum
How to use checksums
c352310d979d8a1dfbffb85279ba671ce26bd3dcdf547f68032914804ea4db76
BLAKE2b-256 checksum
How to use checksums
7576f2f27d2d31db8291223ad1b8b2ecfb6095aa77465b64f8959de8e7f76c0b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-py2.7.egg

Download URL jspcapy-0.4.0.post2-py2.7.egg
Size 4.3 kB
Tags Egg
SHA-256 checksum
How to use checksums
0731676f54dcdefe1e4c4c875ab1671efcba9a12048c2d479e7dc00b92cdae25
BLAKE2b-256 checksum
How to use checksums
349ccb46c4b533c813aeb4c4b0f40308aa8f97ae969f5023625deff60c7a4783
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-pp35-none-macosx_10_14_x86_64.whl

Download URL jspcapy-0.4.0.post2-pp35-none-macosx_10_14_x86_64.whl
Size 16.9 kB
Tags PyPy 3.5 macOS 10.14+ x86-64
SHA-256 checksum
How to use checksums
9f99a3488c3cf4e5a02a07dc9a5b1d0d95687843f903434c8c8325b20a49298a
BLAKE2b-256 checksum
How to use checksums
b0ece97740f99690bd7ed5d0d8d6a67c0d1add704c0409c9757fc94d42760d4b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-pp27-none-macosx_10_14_x86_64.whl

Download URL jspcapy-0.4.0.post2-pp27-none-macosx_10_14_x86_64.whl
Size 16.9 kB
Tags PyPy 2.7 macOS 10.14+ x86-64
SHA-256 checksum
How to use checksums
4ac38b87c465d383251ea76b852e19d8c90eb211c527a961067ee56ae302ea4b
BLAKE2b-256 checksum
How to use checksums
ba639863969f102d6ecebff2c511f1c969e7c0e5e8a2398af167b2c0fca39e8c
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-cp37-none-macosx_10_14_x86_64.whl

Download URL jspcapy-0.4.0.post2-cp37-none-macosx_10_14_x86_64.whl
Size 16.9 kB
Tags CPython 3.7 macOS 10.14+ x86-64
SHA-256 checksum
How to use checksums
7d7e5e10d5ddcef5155a35e841105bf0a4eab95441b6583bd0c7edb9f9201f96
BLAKE2b-256 checksum
How to use checksums
195b798864740122ff5c2071ab5e05f230e1851976c50438f6cd7407bb9e2952
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-cp36-none-macosx_10_14_x86_64.whl

Download URL jspcapy-0.4.0.post2-cp36-none-macosx_10_14_x86_64.whl
Size 16.9 kB
Tags CPython 3.6 macOS 10.14+ x86-64
SHA-256 checksum
How to use checksums
bff213326b27277372e527717e1db39317061cf2a4f14f9c06905d77332f5358
BLAKE2b-256 checksum
How to use checksums
34fe5f8b0addd152c2d5082d672c98683ce736af5e45a4b632b0a991da2ecd7b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release files / jspcapy-0.4.0.post2-cp27-none-macosx_10_14_x86_64.whl

Download URL jspcapy-0.4.0.post2-cp27-none-macosx_10_14_x86_64.whl
Size 16.9 kB
Tags CPython 2.7 macOS 10.14+ x86-64
SHA-256 checksum
How to use checksums
a1e39be8ebe8cd6017225f4b80daef04e3330a7f532bf4dcc80dbcd4e4e860ba
BLAKE2b-256 checksum
How to use checksums
698e434d5177736128f9beb2e4b629b816bd1abbdae3d3c52d71b34d14c9928b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.7.1

Release history Release notifications | RSS feed

This release

0.4.0.post2 This release

11 release files

0.4.0

2 release files

0.3.0

1 release file

0.2.5

1 release file

0.2.4

1 release file

0.2.2

1 release file

0.2.1

1 release file

0.2.0

1 release file

0.1.3

1 release file

0.1.1

1 release file

0.1.0

1 release file

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page